pub struct RoundModifier {
pub roundness: ExprHandle,
}Expand description
Makes particles round.
The shape of each particle is a squircle (like a rounded rectangle, but
faster to evaluate). The roundness parameter specifies how round the shape
is. At 0.0, the particle is a rectangle; at 1.0, the particle is an
ellipse.
Given x and y from (-1, 1), the equation of the shape of the particle is |x|ⁿ + |y|ⁿ = 1, where n = 2 / `roundness``.
Note that this modifier is presently incompatible with the
FlipbookModifier. Attempts to use them together will produce unexpected
results.
Fields
roundness: ExprHandleHow round the particle is.
This ranges from 0.0 for a perfect rectangle to 1.0 for a perfect ellipse. 1/3 produces a nice rounded rectangle shape.
n in the squircle formula is calculated as (2 / roundness).
Implementations
Sourceimpl RoundModifier
impl RoundModifier
Sourcepub fn constant(module: &mut Module, roundness: f32) -> RoundModifier
pub fn constant(module: &mut Module, roundness: f32) -> RoundModifier
Creates a new RoundModifier with the given roundness.
The roundness parameter varies from 0.0 to 1.0.
Sourcepub fn ellipse(module: &mut Module) -> RoundModifier
pub fn ellipse(module: &mut Module) -> RoundModifier
Creates a new RoundModifier that describes an ellipse.