pub enum UnaryOperator {
Show 31 variants
Abs,
Acos,
Asin,
Atan,
All,
Any,
Ceil,
Cos,
Exp,
Exp2,
Floor,
Fract,
InvSqrt,
Length,
Log,
Log2,
Normalize,
Pack4x8snorm,
Pack4x8unorm,
Round,
Saturate,
Sign,
Sin,
Sqrt,
Tan,
Unpack4x8snorm,
Unpack4x8unorm,
W,
X,
Y,
Z,
}Expand description
Unary operator.
Operator applied to a single operand to produce another value. The type of the operand and the result are not necessarily the same. Valid operand types depend on the operator itself.
Variants
Abs
Absolute value operator.
Return the absolute value of the operand, component-wise for vectors. Only valid for numeric operands.
Acos
Inverse cosine operator.
Return the inverse cosine of the operand, component-wise for vectors. Only valid for floating-point operands.
Asin
Inverse sine operator.
Return the inverse sine of the operand, component-wise for vectors. Only valid for floating-point operands.
Atan
Inverse tangent operator.
Return the inverse tangent of the operand, component-wise for vectors. Only valid for floating-point operands.
All
Logical ALL operator for bool vectors.
Return true if all the components of the bool vector operand are
true. Invalid for any other type of operand.
Any
Logical ANY operator for bool vectors.
Return true if any component of the bool vector operand is true.
Invalid for any other type of operand.
Ceil
Ceiling operator.
Return the unique integral number k such that k-1 < x <= k, where
x is the operand which the operator applies to.
Cos
Cosine operator.
Exp
Natural exponent operator.
Return the natural exponentiation of the operand (e^x), component-wise
for vectors.
Exp2
Base-2 exponent operator.
Return two raised to the power of the operand (2^x), component-wise
for vectors.
Floor
Floor operator.
Return the unique integral number k such that k <= x < k+1, where
x is the operand which the operator applies to.
Fract
Fractional part operator.
Return the fractional part of the operand, which is equal to x - floor(x), component-wise for vectors.
InvSqrt
Inverse square root operator.
Return the inverse square root of the floating-point operand (1.0 / sqrt(x)), component-wise for vectors.
Length
Length operator.
Return the length of a floating point scalar or vector. The “length” of
a scalar is taken as its absolute value. The length of a vector is the
Euclidian distance sqrt(x^2 + ...) (square root of the sum of the
squared components).
The output is always a floating point scalar.
Log
Natural logarithm operator.
Return the natural logarithm of the operand (log(x)), component-wise
for vectors.
Log2
Base-2 logarithm operator.
Return the base-2 logarithm of the operand (log2(x)), component-wise
for vectors.
Normalize
Vector normalizing operator.
Normalize the given numeric vector. Only valid for numeric vector operands.
Pack4x8snorm
Packing operator from vec4<f32> to u32 (signed normalized).
Convert the four components of a signed normalized floating point vector
into a signed integral i8 value in [-128:127], then pack those
four values into a single u32. Each vector component should be in
[-1:1] before packing; values outside this range are clamped.
Pack4x8unorm
Packing operator from vec4<f32> to u32 (unsigned normalized).
Convert the four components of an unsigned normalized floating point
vector into an unsigned integral u8 value in [0:255], then pack
those four values into a single u32. Each vector component should
be in [0:1] before packing; values outside this range are clamped.
Round
Rounding operator.
Round the given scalar of vector float to the nearest integer, returned as a float value.
Saturate
Saturate operator.
Clamp the value of the operand to the [0:1] range, component-wise for vectors.
Sign
Sign operator.
Return a value representing the sign of a floating point scalar or vector input:
1.if the operand is > 00.if the operand is = 0-1.if the operand is < 0
Applies component-wise for vectors.
Sin
Sine operator.
Sqrt
Square root operator.
Return the square root of the floating-point operand, component-wise for vectors.
Tan
Tangent operator.
Unpack4x8snorm
Unpacking operator from u32 to vec4<f32> (signed normalized).
Unpack the u32 into four signed integral i8 value in [-128:127],
then convert each value to a signed normalized f32 value in [-1:1].
Unpack4x8unorm
Unpacking operator from u32 to vec4<f32> (unsigned normalized).
Unpack the u32 into four unsigned integral u8 value in [0:255],
then convert each value to an unsigned normalized f32 value in
[0:1].
W
Get the fourth component of a vector.
This is only valid for vectors of rank 4.
X
Get the first component of a scalar or vector.
For scalar, return the value itself. For vectors, return the first component.
Y
Get the second component of a vector.
Z
Get the third component of a vector.
This is only valid for vectors of rank 3 or more.
Implementations
Sourceimpl UnaryOperator
impl UnaryOperator
Sourcepub fn is_functional(&self) -> bool
pub fn is_functional(&self) -> bool
Check if a unary operator is called via a functional-style call.
Functional-style calls are in the form op(inner), like abs(x) for
example, while non-functional ones are in the form inner.op,
like v.x for example. This check is used for formatting the WGSL
code emitted during evaluation of a binary operation expression.